=== modified file 'NEWS'
--- NEWS	2009-08-20 13:30:37 +0000
+++ NEWS	2009-10-21 13:21:02 +0000
@@ -1,6 +1,13 @@
 What's changed in loggerhead?
 =============================
 
+dev [future]
+------------
+
+    - Fix .bzr/smart access to branches in shared repos. (You also need
+      a version of bzr with bug #348308 fixed.) (Andrew Bennetts)
+
+
 1.17 [20Aug2009]
 ---------------
 

=== modified file '__init__.py'
--- __init__.py	2009-10-17 06:35:33 +0000
+++ __init__.py	2009-10-09 16:23:47 +0000
@@ -59,9 +59,6 @@
             (DEFAULT_PORT,))
 
     def serve_http(transport, host=None, port=None, inet=None):
-        from paste.httpexceptions import HTTPExceptionHandler
-        from paste.httpserver import serve
-
         # loggerhead internal code will try to 'import loggerhead', so
         # let's put it on the path if we can't find it in the existing path
         try:
@@ -72,7 +69,8 @@
 
         from loggerhead.apps.transport import BranchesFromTransportRoot
         from loggerhead.config import LoggerheadConfig
-
+        from paste.httpexceptions import HTTPExceptionHandler
+        from paste.httpserver import serve
         if host is None:
             host = DEFAULT_HOST
         if port is None:

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2009-10-17 06:35:33 +0000
+++ loggerhead/apps/branch.py	2009-05-28 08:17:40 +0000
@@ -52,7 +52,7 @@
         self._config = config
         self.friendly_name = friendly_name
         self.branch_link = branch_link  # Currently only used in Launchpad
-        self.log = logging.getLogger('loggerhead.%s' % (friendly_name,))
+        self.log = logging.getLogger('loggerhead.%s' % friendly_name)
         if graph_cache is None:
             graph_cache = bzrlib.lru_cache.LRUCache(10)
         self.graph_cache = graph_cache
@@ -86,7 +86,7 @@
         qs = []
         for k, v in kw.iteritems():
             if v is not None:
-                qs.append('%s=%s' % (k, urllib.quote(v)))
+                qs.append('%s=%s'%(k, urllib.quote(v)))
         qs = '&'.join(qs)
         return request.construct_url(
             self._environ, script_name=self._url_base,

=== modified file 'loggerhead/apps/error.py'
--- loggerhead/apps/error.py	2009-10-17 08:47:38 +0000
+++ loggerhead/apps/error.py	2008-10-24 02:26:05 +0000
@@ -53,6 +53,6 @@
 
 
 def errapp(environ, start_response):
-    """Default (and trivial) error handling WSGI application."""
+    '''Default (and trivial) error handling WSGI application.'''
     c = ErrorUI(environ['branch'], environ['exc_info'])
     return c(environ, start_response)

=== modified file 'loggerhead/apps/transport.py'
--- loggerhead/apps/transport.py	2009-10-17 06:35:33 +0000
+++ loggerhead/apps/transport.py	2009-10-21 13:05:17 +0000
@@ -20,6 +20,7 @@
 
 from bzrlib import branch, errors, lru_cache, urlutils
 from bzrlib.config import LocationConfig
+from bzrlib.smart import request
 from bzrlib.transport import get_transport
 from bzrlib.transport.http import wsgi
 
@@ -54,13 +55,10 @@
             name = self.name
             is_root = False
         branch_app = BranchWSGIApp(
-            branch,
-            name,
+            branch, name,
             {'cachepath': self._config.SQL_DIR},
-            self.root.graph_cache,
-            is_root=is_root,
-            use_cdn=self._config.get_option('use_cdn'),
-            )
+            self.root.graph_cache, is_root=is_root,
+            use_cdn=self._config.get_option('use_cdn'))
         return branch_app.app
 
     def app_for_non_branch(self, environ):
@@ -85,8 +83,9 @@
 
     def app_for_bazaar_data(self, relpath):
         if relpath == '/.bzr/smart':
-            wsgi_app = wsgi.SmartWSGIApp(self.transport)
-            return wsgi.RelpathSetter(wsgi_app, '', 'PATH_INFO')
+            root_transport = get_transport_for_thread(self.root.base)
+            wsgi_app = wsgi.SmartWSGIApp(root_transport)
+            return wsgi.RelpathSetter(wsgi_app, '', 'loggerhead.path_info')
         else:
             # TODO: Use something here that uses the transport API
             # rather than relying on the local filesystem API.
@@ -137,6 +136,7 @@
     if base in thread_transports:
         return thread_transports[base]
     transport = get_transport(base)
+    thread_transports[base] = transport
     return transport
 
 
@@ -149,6 +149,7 @@
 
     def __call__(self, environ, start_response):
         environ['loggerhead.static.url'] = environ['SCRIPT_NAME']
+        environ['loggerhead.path_info'] = environ['PATH_INFO']
         if environ['PATH_INFO'].startswith('/static/'):
             segment = path_info_pop(environ)
             assert segment == 'static'
@@ -171,6 +172,7 @@
 
     def __call__(self, environ, start_response):
         environ['loggerhead.static.url'] = environ['SCRIPT_NAME']
+        environ['loggerhead.path_info'] = environ['PATH_INFO']
         path_info = environ['PATH_INFO']
         if path_info.startswith('/static/'):
             segment = path_info_pop(environ)

=== modified file 'loggerhead/config.py'
--- loggerhead/config.py	2009-10-17 08:47:38 +0000
+++ loggerhead/config.py	2009-06-03 23:21:52 +0000
@@ -11,7 +11,7 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-"""Configuration tools for Loggerhead."""
+'''Configuration tools for Loggerhead.'''
 
 from optparse import OptionParser
 import sys
@@ -37,7 +37,7 @@
         sql_dir=None,
         allow_writes=False,
         )
-    parser.add_option("--user-dirs", action="store_true",
+    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
                       help="Serve user directories as ~user.")
     parser.add_option("--trunk-dir", metavar="DIR",
                       help="The directory that contains the trunk branches.")
@@ -46,31 +46,32 @@
                             "(defaults to 8080)."))
     parser.add_option("--host", dest="user_host",
                       help="Host Loggerhead should listen on.")
-    parser.add_option("--memory-profile", action="store_true",
-                      help="Profile the memory usage using Dozer.")
+    parser.add_option('--memory-profile', action='store_true',
+                      dest='memory_profile',
+                      help='Profile the memory usage using Dozer.')
     parser.add_option("--prefix", dest="user_prefix",
                       help="Specify host prefix.")
-    parser.add_option("--profile", action="store_true",
+    parser.add_option("--profile", action="store_true", dest="profile",
                       help="Generate callgrind profile data to "
                         "%d-stats.callgrind on each request.")
-    parser.add_option("--reload", action="store_true",
+    parser.add_option("--reload", action="store_true", dest="reload",
                       help="Restarts the application when changing python"
                            " files. Only used for development purposes.")
-    parser.add_option("--log-folder",
-                      help="The directory to place log files in.")
+    parser.add_option('--log-folder', dest="log_folder",
+                      type=str, help="The directory to place log files in.")
     parser.add_option("--version", action="store_true", dest="show_version",
                       help="Print the software version and exit")
     parser.add_option("--use-cdn", action="store_true", dest="use_cdn",
                       help="Serve YUI from Yahoo!'s CDN")
     parser.add_option("--cache-dir", dest="sql_dir",
                       help="The directory to place the SQL cache in")
-    parser.add_option("--allow-writes", action="store_true",
+    parser.add_option('--allow-writes', action='store_true',
                       help="Allow writing to the Bazaar server.")
     return parser
 
 
 class LoggerheadConfig(object):
-    """A configuration object."""
+    '''A configuration object.'''
 
     def __init__(self, argv=None):
         if argv is None:
@@ -85,13 +86,12 @@
 
     def get_option(self, option):
         """Get the value for the config option, either 
-        from ~/.bazaar/bazaar.conf or from the command line.
-        All loggerhead-specific settings start with 'http_'
-        """
+           from ~/.bazaar/bazaar.conf or from the command line.
+           All loggerhead-specific settings start with 'http_'"""
         global_config = config.GlobalConfig().get_user_option('http_'+option)
         cmd_config = getattr(self._options, option)
         if global_config is not None and (
-            cmd_config is None or cmd_config is False):
+                cmd_config is None or cmd_config is False):
             return global_config
         else:
             return cmd_config
@@ -108,3 +108,4 @@
     def arg_count(self):
         """Return the number of args from the option parser."""
         return len(self._args)
+

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2009-10-17 08:59:33 +0000
+++ loggerhead/controllers/__init__.py	2009-03-02 05:44:20 +0000
@@ -70,7 +70,7 @@
         kwargs = dict(parse_querystring(environ))
         util.set_context(kwargs)
         args = []
-        while True:
+        while 1:
             arg = path_info_pop(environ)
             if arg is None:
                 break

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2009-10-17 06:35:33 +0000
+++ loggerhead/controllers/annotate_ui.py	2009-05-16 06:05:56 +0000
@@ -62,10 +62,10 @@
         try:
             bzrlib.textfile.check_text_lines(file_lines)
         except bzrlib.errors.BinaryFile:
-            # bail out; this isn't displayable text
-            yield util.Container(parity=0, lineno=1, status='same',
-                                 text='(This is a binary file.)',
-                                 change=util.Container())
+                # bail out; this isn't displayable text
+                yield util.Container(parity=0, lineno=1, status='same',
+                                     text='(This is a binary file.)',
+                                     change=util.Container())
         else:
             if highlight is not None:
                 hl_lines = highlight(file_name, file_text, encoding)
@@ -95,7 +95,7 @@
                     change=change, text=hl_lines[lineno - 1])
                 lineno += 1
 
-        self.log.debug('annotate: %r secs' % (time.time() - z,))
+        self.log.debug('annotate: %r secs' % (time.time() - z))
 
     def get_values(self, path, kwargs, headers):
         history = self._history

=== modified file 'loggerhead/controllers/diff_ui.py'
--- loggerhead/controllers/diff_ui.py	2009-10-17 08:59:33 +0000
+++ loggerhead/controllers/diff_ui.py	2008-12-05 18:52:44 +0000
@@ -38,7 +38,7 @@
         z = time.time()
 
         args = []
-        while True:
+        while 1:
             arg = path_info_pop(environ)
             if arg is None:
                 break
@@ -73,7 +73,7 @@
         headers = [
             ('Content-Type', 'application/octet-stream'),
             ('Content-Length', len(content)),
-            ('Content-Disposition', 'attachment; filename=%s' % (filename,)),
+            ('Content-Disposition', 'attachment; filename=%s' % filename),
             ]
         start_response('200 OK', headers)
         return [content]

=== modified file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	2009-10-17 06:35:33 +0000
+++ loggerhead/controllers/directory_ui.py	2009-06-02 13:39:33 +0000
@@ -57,7 +57,7 @@
             def static_url(path):
                 return self._static_url_base + path
         self._branch = _branch
-        self._history_callable = lambda: None
+        self._history_callable = lambda:None
         self._name = name
         self._static_url_base = static_url_base
         self.transport = transport

=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2009-10-17 08:59:33 +0000
+++ loggerhead/controllers/download_ui.py	2009-07-07 23:52:24 +0000
@@ -37,7 +37,7 @@
         h = self._history
 
         args = []
-        while True:
+        while 1:
             arg = path_info_pop(environ)
             if arg is None:
                 break
@@ -63,7 +63,7 @@
             ('Content-Type', mime_type),
             ('Content-Length', len(content)),
             ('Content-Disposition',
-             'attachment; filename*=utf-8\'\'%s' % (encoded_filename,)),
+             'attachment; filename*=utf-8\'\'%s' % encoded_filename),
             ]
         start_response('200 OK', headers)
         return [content]

=== modified file 'loggerhead/controllers/error_ui.py'
--- loggerhead/controllers/error_ui.py	2009-10-17 08:47:38 +0000
+++ loggerhead/controllers/error_ui.py	2008-12-05 18:52:44 +0000
@@ -28,19 +28,22 @@
     template_path = 'loggerhead.templates.error'
 
     def __init__(self, branch, exc_info):
-        super(ErrorUI, self).__init__(branch, lambda: None)
+        super(ErrorUI, self).__init__(branch, lambda:None)
         self.exc_info = exc_info
 
     def get_values(self, path, kwargs, response):
         exc_type, exc_object, exc_tb = self.exc_info
         description = StringIO()
         traceback.print_exception(exc_type, exc_object, None, file=description)
-        directory_breadcrumbs = util.directory_breadcrumbs(
-            self._branch.friendly_name, self._branch.is_root, 'changes')
+        directory_breadcrumbs = (
+            util.directory_breadcrumbs(
+                self._branch.friendly_name,
+                self._branch.is_root,
+                'changes'))
         return {
             'branch': self._branch,
             'error_title': ('An unexpected error occurred while'
-                            'processing the request:'),
+                            'proccesing the request:'),
             'error_description': description.getvalue(),
             'directory_breadcrumbs': directory_breadcrumbs,
         }

=== modified file 'loggerhead/daemon.py'
--- loggerhead/daemon.py	2009-05-13 14:03:48 +0000
+++ loggerhead/daemon.py	2008-12-07 15:24:05 +0000
@@ -53,7 +53,7 @@
             pass
 
     f = open(pidfile, 'w')
-    f.write('%d\n' % (os.getpid(),))
+    f.write('%d\n' % os.getpid())
     f.close()
 
 

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2009-10-17 08:59:33 +0000
+++ loggerhead/history.py	2009-10-15 23:12:10 +0000
@@ -34,14 +34,14 @@
 import re
 import textwrap
 
+from loggerhead import search
+from loggerhead import util
+from loggerhead.wholehistory import compute_whole_history_data
+
+import bzrlib
 import bzrlib.branch
 import bzrlib.delta
 import bzrlib.errors
-import bzrlib.revision
-
-from loggerhead import search
-from loggerhead import util
-from loggerhead.wholehistory import compute_whole_history_data
 
 
 def is_branch(folder):
@@ -104,7 +104,6 @@
         return len(self.revid_list)
 
 class FileChangeReporter(object):
-
     def __init__(self, old_inv, new_inv):
         self.added = []
         self.modified = []
@@ -188,7 +187,7 @@
         self._cache[key] = (revid, data)
 
 
-class History(object):
+class History (object):
     """Decorate a branch to provide information for rendering.
 
     History objects are expected to be short lived -- when serving a request
@@ -262,7 +261,7 @@
         self._branch = branch
         self._inventory_cache = {}
         self._branch_nick = self._branch.get_config().get_nickname()
-        self.log = logging.getLogger('loggerhead.%s' % (self._branch_nick,))
+        self.log = logging.getLogger('loggerhead.%s' % self._branch_nick)
 
         self.last_revid = branch.last_revision()
 
@@ -305,7 +304,7 @@
                 r.add(self._rev_info[i][0][1])
                 i += 1
             return r
-        while True:
+        while 1:
             if bzrlib.revision.is_null(revid):
                 return
             if introduced_revisions(revid) & revid_set:
@@ -555,7 +554,7 @@
             else:
                 d[revnos] = (revnolast, revid)
 
-        return [revid for (_, revid) in d.itervalues()]
+        return [d[revnos][1] for revnos in d.iterkeys()]
 
     def add_branch_nicks(self, change):
         """
@@ -669,7 +668,7 @@
         entry.changes = changes
 
     def get_file(self, file_id, revid):
-        """Returns (path, filename, file contents)"""
+        "returns (path, filename, data)"
         inv = self.get_inventory(revid)
         inv_entry = inv[file_id]
         rev_tree = self._branch.repository.revision_tree(inv_entry.revision)
@@ -692,8 +691,8 @@
             text_changes: list((filename, file_id)),
         """
         repo = self._branch.repository
-        if (bzrlib.revision.is_null(old_revid) or
-            bzrlib.revision.is_null(new_revid)):
+        if bzrlib.revision.is_null(old_revid) or \
+               bzrlib.revision.is_null(new_revid):
             old_tree, new_tree = map(
                 repo.revision_tree, [old_revid, new_revid])
         else:
@@ -704,8 +703,8 @@
         bzrlib.delta.report_changes(new_tree.iter_changes(old_tree), reporter)
 
         return util.Container(
-            added=sorted(reporter.added, key=lambda x: x.filename),
-            renamed=sorted(reporter.renamed, key=lambda x: x.new_filename),
-            removed=sorted(reporter.removed, key=lambda x: x.filename),
-            modified=sorted(reporter.modified, key=lambda x: x.filename),
-            text_changes=sorted(reporter.text_changes, key=lambda x: x.filename))
+            added=sorted(reporter.added, key=lambda x:x.filename),
+            renamed=sorted(reporter.renamed, key=lambda x:x.new_filename),
+            removed=sorted(reporter.removed, key=lambda x:x.filename),
+            modified=sorted(reporter.modified, key=lambda x:x.filename),
+            text_changes=sorted(reporter.text_changes, key=lambda x:x.filename))

=== modified file 'loggerhead/main.py'
--- loggerhead/main.py	2009-10-17 06:35:33 +0000
+++ loggerhead/main.py	2009-07-07 23:52:24 +0000
@@ -39,7 +39,7 @@
     config = LoggerheadConfig(args)
 
     if config.get_option('show_version'):
-        print "loggerhead %s" % (__version__,)
+        print "loggerhead %s" % __version__
         sys.exit(0)
 
     if config.arg_count > 1:

=== modified file 'loggerhead/middleware/profile.py'
--- loggerhead/middleware/profile.py	2009-10-17 08:47:38 +0000
+++ loggerhead/middleware/profile.py	2009-06-26 18:38:37 +0000
@@ -4,7 +4,6 @@
 
 from bzrlib.lsprof import profile
 
-
 class LSProfMiddleware(object):
     """Paste middleware for profiling with lsprof."""
 
@@ -27,7 +26,7 @@
         try:
             ret, stats = profile(self.__run_app, environ, start_response)
             self.__count += 1
-            stats.save("%d-stats.callgrind" % (self.__count,), format="callgrind")
+            stats.save("%d-stats.callgrind" % self.__count, format="callgrind")
             return ret
         finally:
             self.lock.release()

=== modified file 'loggerhead/search.py'
--- loggerhead/search.py	2009-04-17 03:38:04 +0000
+++ loggerhead/search.py	2009-04-17 01:50:05 +0000
@@ -17,7 +17,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-
 _mod_index = None
 def import_search():
     global errors, _mod_index, FileTextHit, RevisionHit

=== modified file 'loggerhead/templatefunctions.py'
--- loggerhead/templatefunctions.py	2009-10-17 08:47:38 +0000
+++ loggerhead/templatefunctions.py	2009-08-04 04:51:44 +0000
@@ -56,7 +56,7 @@
                     url, entry.revno, filename, '#' + filename)
     else:
         def file_link(filename):
-            return '<a href="%s%s" title="View changes to %s in revision %s">%s</a>' % (
+            return '<a href="%s%s" title="View changes to %s in revision %s">%s</a>'%(
                 url(['/revision', entry.revno]), '#' + filename, cgi.escape(filename),
                 cgi.escape(entry.revno), cgi.escape(filename))
     return _pt('revisionfilechanges').expand(
@@ -100,7 +100,7 @@
         extra = ' ' + entry.branch_nick
     else:
         extra = ''
-    return '(%s%s)' % (entry.revno, extra)
+    return '(%s%s)'%(entry.revno, extra)
 
 
 @templatefunc
@@ -122,12 +122,12 @@
 
 @templatefunc
 def annotate_link(url, revno, path):
-    return '<a href="%s" title="Annotate %s">%s</a>' % (
+    return '<a href="%s" title="Annotate %s">%s</a>'%(
         url(['/annotate', revno, path]), cgi.escape(path), cgi.escape(path))
 
 @templatefunc
 def revision_link(url, revno, path, frag=''):
-    return '<a href="%s%s" title="View changes to %s in revision %s">%s</a>' % (
+    return '<a href="%s%s" title="View changes to %s in revision %s">%s</a>'%(
         url(['/revision', revno, path]), frag, cgi.escape(path),
         cgi.escape(revno), cgi.escape(path))
 

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2009-10-17 06:35:33 +0000
+++ loggerhead/util.py	2009-07-07 23:52:24 +0000
@@ -19,6 +19,13 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+try:
+    from xml.etree import ElementTree as ET
+except ImportError:
+    from elementtree import ElementTree as ET
+
+from simpletal.simpleTALUtils import HTMLStructureCleaner
+
 import base64
 import cgi
 import datetime
@@ -31,13 +38,6 @@
 import os
 import subprocess
 
-try:
-    from xml.etree import ElementTree as ET
-except ImportError:
-    from elementtree import ElementTree as ET
-
-from simpletal.simpleTALUtils import HTMLStructureCleaner
-
 log = logging.getLogger("loggerhead.controllers")
 
 
@@ -129,7 +129,7 @@
     return _wrap_with_date_time_title(date, _displaydate(date))
 
 
-class Container(object):
+class Container (object):
     """
     Convert a dict into an object with attributes.
     """
@@ -217,6 +217,8 @@
 
     return: the same value recieved if not empty, and a '&nbsp;' if it is.
     """
+
+
     if s is None:
         return '&nbsp;'
     elif isinstance(s, int):
@@ -314,7 +316,7 @@
 
     out = str(base)
     if (base < 100) and (dot != 0):
-        out += '.%d' % (dot,)
+        out += '.%d' % (dot)
     if divisor == KILO:
         out += 'K'
     elif divisor == MEG:
@@ -461,7 +463,7 @@
         now = time.time()
         msec = int(now * 1000) % 1000
         timestr = time.strftime('%Y%m%d%H%M%S',
-                                time.localtime(now)) + ('%03d' % (msec,))
+                                time.localtime(now)) + ('%03d' % msec)
         filename = f.__name__ + '-' + timestr + '.lsprof'
         cPickle.dump(stats, open(filename, 'w'), 2)
         return ret
@@ -533,7 +535,7 @@
     _reloader_environ_key = 'PYTHON_RELOADER_SHOULD_RUN'
 
     @classmethod
-    def _turn_sigterm_into_systemexit(cls):
+    def _turn_sigterm_into_systemexit(self):
         """
         Attempts to turn a SIGTERM exception into a SystemExit exception.
         """
@@ -547,26 +549,26 @@
         signal.signal(signal.SIGTERM, handle_term)
 
     @classmethod
-    def is_installed(cls):
-        return os.environ.get(cls._reloader_environ_key)
+    def is_installed(self):
+        return os.environ.get(self._reloader_environ_key)
 
     @classmethod
-    def install(cls):
+    def install(self):
         from paste import reloader
         reloader.install(int(1))
 
     @classmethod
-    def restart_with_reloader(cls):
+    def restart_with_reloader(self):
         """Based on restart_with_monitor from paste.script.serve."""
         print 'Starting subprocess with file monitor'
-        while True:
+        while 1:
             args = [sys.executable] + sys.argv
             new_environ = os.environ.copy()
-            new_environ[cls._reloader_environ_key] = 'true'
+            new_environ[self._reloader_environ_key] = 'true'
             proc = None
             try:
                 try:
-                    cls._turn_sigterm_into_systemexit()
+                    self._turn_sigterm_into_systemexit()
                     proc = subprocess.Popen(args, env=new_environ)
                     exit_code = proc.wait()
                     proc = None
@@ -575,7 +577,7 @@
                     return 1
             finally:
                 if (proc is not None
-                    and getattr(os, 'kill', None) is not None):
+                    and hasattr(os, 'kill')):
                     import signal
                     try:
                         os.kill(proc.pid, signal.SIGTERM)

=== modified file 'loggerhead/wholehistory.py'
--- loggerhead/wholehistory.py	2009-10-17 08:47:38 +0000
+++ loggerhead/wholehistory.py	2009-10-15 23:12:10 +0000
@@ -48,7 +48,7 @@
     last_revid = branch.last_revision()
 
     log = logging.getLogger('loggerhead.%s' %
-                            (branch.get_config().get_nickname(),))
+                            branch.get_config().get_nickname())
 
     graph = branch.repository.get_graph()
     parent_map = dict(((key, value) for key, value in
@@ -80,6 +80,6 @@
             if revid not in c[1]:
                 c[1] = c[1] + (revid,)
 
-    log.info('built revision graph cache: %r secs' % (time.time() - z,))
+    log.info('built revision graph cache: %r secs' % (time.time() - z))
 
     return (_rev_info, _rev_indices)

=== modified file 'setup.py'
--- setup.py	2009-10-17 06:19:40 +0000
+++ setup.py	2009-06-02 22:10:00 +0000
@@ -18,8 +18,8 @@
 
 """Loggerhead is a web viewer for projects in bazaar"""
 
+
 from distutils.core import setup
-
 import loggerhead
 
 

=== modified file 'start-loggerhead'
--- start-loggerhead	2009-10-17 06:35:33 +0000
+++ start-loggerhead	2009-06-08 23:02:49 +0000
@@ -20,6 +20,7 @@
 
 
 import logging
+import logging.handlers
 from optparse import OptionParser
 import os
 import sys
@@ -34,7 +35,7 @@
 
 from loggerhead import daemon
 from loggerhead.apps.config import Root
-from loggerhead.trace import setup_logging
+from loggerhead.trace import make_handler, setup_logging
 from loggerhead.apps.error import ErrorHandlerApp
 
 
@@ -102,7 +103,7 @@
     if not options.foreground:
         sys.stderr.write('\n')
         sys.stderr.write('Launching loggerhead into the background.\n')
-        sys.stderr.write('PID file: %s\n' % (options.pidfile,))
+        sys.stderr.write('PID file: %s\n' % options.pidfile)
         sys.stderr.write('\n')
 
         daemon.daemonize(options.pidfile, home)

=== modified file 'stop-loggerhead'
--- stop-loggerhead	2009-05-13 14:03:48 +0000
+++ stop-loggerhead	2008-10-24 02:26:05 +0000
@@ -32,7 +32,7 @@
 try:
     f = open(options.pidfile, 'r')
 except IOError, e:
-    print 'Pid file %s not found.' % (options.pidfile,)
+    print 'Pid file %s not found.' % options.pidfile
     sys.exit(1)
 
 pid = int(f.readline())
@@ -44,7 +44,7 @@
     sys.exit(1)
 
 print
-print 'Shutting down previous server @ pid %d.' % (pid,)
+print 'Shutting down previous server @ pid %d.' % pid
 print
 
 import signal

